<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'travel_master_pro_package_section', array(
	'title'             => esc_html__( 'Package','travel-master-pro' ),
	'description'       => esc_html__( 'Package Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_package_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// package title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_package_section',
	'active_callback' 	=> 'travel_master_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[package_title]', array(
		'selector'            => '#recommended-hotels .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_package_title_partial',
    ) );
}

// Package content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_package_section_enable',
	'choices'			=> travel_master_pro_package_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[package_content_category]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Category_Control( $wp_customize,'travel_master_pro_theme_options[package_content_category]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_package_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_master_pro_is_package_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[package_content_trip_types]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Category_Control( $wp_customize,'travel_master_pro_theme_options[package_content_trip_types]', array(
	'label'             => esc_html__( 'Select Multiple Trip Types', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_package_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_master_pro_is_package_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[package_content_activity]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Category_Control( $wp_customize,'travel_master_pro_theme_options[package_content_activity]', array(
	'label'             => esc_html__( 'Select Multiple Activities', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_package_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_master_pro_is_package_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[package_content_destination]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Category_Control( $wp_customize,'travel_master_pro_theme_options[package_content_destination]', array(
	'label'             => esc_html__( 'Select Multiple Destination', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_package_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_master_pro_is_package_section_content_destination_enable'
) ) );

// package title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[package_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[package_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_package_section',
	'active_callback' 	=> 'travel_master_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[package_btn_title]', array(
		'selector'            => '#recommended-hotels .read-more a.btn',
		'settings'            => 'travel_master_pro_theme_options[package_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_package_btn_title_partial',
    ) );
}

// package btn url setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[package_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[package_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_package_section',
	'active_callback' 	=> 'travel_master_pro_is_package_section_enable',
	'type'				=> 'url',
) );


$wp_customize->add_setting(	
	'travel_master_pro_theme_options[package_btn_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[package_btn_color]',
		array(
			'section'		=> 'travel_master_pro_package_section',
			'label'			=> esc_html__( 'Btn Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[package_btn_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[package_btn_hover_color]',
		array(
			'section'		=> 'travel_master_pro_package_section',
			'label'			=> esc_html__( 'Btn Hover Color', 'travel-master-pro' ),

		)
	)
); 

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[package_btn_text_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[package_btn_text_color]',
		array(
			'section'		=> 'travel_master_pro_package_section',
			'label'			=> esc_html__( 'Btn Text Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[package_btn_text_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[package_btn_text_hover_color]',
		array(
			'section'		=> 'travel_master_pro_package_section',
			'label'			=> esc_html__( 'Btn Text Hover Color', 'travel-master-pro' ),

		)
	)
); 

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[package_btn_border_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[package_btn_border_color]',
		array(
			'section'		=> 'travel_master_pro_package_section',
			'label'			=> esc_html__( 'Btn Border Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[package_btn_border_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[package_btn_border_hover_color]',
		array(
			'section'		=> 'travel_master_pro_package_section',
			'label'			=> esc_html__( 'Btn Border Hover Color', 'travel-master-pro' ),

		)
	)
); 