<?php
/**
 * popular Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add popular section
$wp_customize->add_section( 'travel_master_pro_popular_section', array(
	'title'             => esc_html__( 'Popular Posts','travel-master-pro' ),
	'description'       => esc_html__( 'Popular Posts Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// popular content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[popular_section_enable]', array(
	'default'			=> 	$options['popular_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[popular_section_enable]', array(
	'label'             => esc_html__( 'popular Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_popular_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );


// popular content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[popular_content_type]', array(
	'default'          	=> $options['popular_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[popular_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_popular_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_popular_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-master-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-master-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-master-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'travel-master-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[popular_count]', array(
	'default'          	=> $options['popular_count'],
	'sanitize_callback' => 'travel_master_pro_sanitize_number_range',
	'validate_callback' => 'travel_master_pro_validate_popular_count',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[popular_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-master-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_popular_section',
	'active_callback'   => 'travel_master_pro_is_popular_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['popular_count']; $i++ ) :
	// popular pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[popular_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[popular_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_popular_section',
		'choices'			=> travel_master_pro_page_choices(),
		'active_callback'	=> 'travel_master_pro_is_popular_section_content_page_enable',
	) ) );

	// popular posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[popular_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[popular_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_popular_section',
		'choices'			=> travel_master_pro_post_choices(),
		'active_callback'	=> 'travel_master_pro_is_popular_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[popular_content_category]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[popular_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_popular_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_popular_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'travel_master_pro_theme_options[popular_category_exclude]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Category_Control( $wp_customize,'travel_master_pro_theme_options[popular_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_popular_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_master_pro_is_popular_section_content_recent_enable'
) ) );
